==> ui-framework-4.5.4-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractWidgetSummaryMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractWidgetSummaryMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, io.intino.alexandria.schemas.Widget, B> {
	public Doc_27_1_01474993905 doc_27_1_01474993905;
	public WidgetSummaryMold.Doc_27_1_01474993905. Title title;
	public WidgetSummaryMold.Doc_27_1_01474993905. Doc_29_2_1203325673 doc_29_2_1203325673;
	public WidgetSummaryMold.Doc_27_1_01474993905.Doc_29_2_1203325673. Description description;
	public WidgetSummaryMold.Doc_27_1_01474993905. Facets facets;

    public AbstractWidgetSummaryMold(B box) {
        super(box);
        id("widgetSummaryMold");
    }

    @Override
	public void init() {
		super.init();
		if (doc_27_1_01474993905 == null) doc_27_1_01474993905 = register(new Doc_27_1_01474993905(box()).<Doc_27_1_01474993905>id("a628581916").owner(AbstractWidgetSummaryMold.this));
		if (doc_27_1_01474993905 != null) title = doc_27_1_01474993905.title;
		if (doc_27_1_01474993905 != null) doc_29_2_1203325673 = doc_27_1_01474993905.doc_29_2_1203325673;
		if (doc_29_2_1203325673 != null) description = doc_27_1_01474993905.doc_29_2_1203325673.description;
		if (doc_27_1_01474993905 != null) facets = doc_27_1_01474993905.facets;
	}

	public class Doc_27_1_01474993905 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public WidgetSummaryMold.Doc_27_1_01474993905. Title title;
		public WidgetSummaryMold.Doc_27_1_01474993905. Doc_29_2_1203325673 doc_29_2_1203325673;
		public WidgetSummaryMold.Doc_27_1_01474993905. Facets facets;

		public Doc_27_1_01474993905(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (title == null) title = register(new Title(box()).<Title>id("a_1507377868").owner(AbstractWidgetSummaryMold.this));
			if (doc_29_2_1203325673 == null) doc_29_2_1203325673 = register(new Doc_29_2_1203325673(box()).<Doc_29_2_1203325673>id("a_1927398662").owner(AbstractWidgetSummaryMold.this));
			if (facets == null) facets = register(new Facets(box()).<Facets>id("a107217472").owner(AbstractWidgetSummaryMold.this));
		}

		public class Title extends io.intino.alexandria.ui.displays.components.OpenPage<io.intino.alexandria.ui.displays.notifiers.OpenPageNotifier, B>  {

			public Title(B box) {
				super(box);
				_title("");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
				_path("/docs/data/:type");
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Doc_29_2_1203325673 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public WidgetSummaryMold.Doc_27_1_01474993905.Doc_29_2_1203325673. Description description;

			public Doc_29_2_1203325673(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (description == null) description = register(new Description(box()).<Description>id("a2023875803").owner(AbstractWidgetSummaryMold.this));
			}

			public class Description extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Description(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class Facets extends io.intino.alexandria.ui.displays.components.Multiple<B,Text, java.lang.String>  {

			public Facets(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public Text add(java.lang.String value) {
				Text child = new Text(box());
				child.id(java.util.UUID.randomUUID().toString());
				add(child, "facets");
				child.value(value);
			    notifyAdd(child, value);
				return child;
			}
			@Override
			public void remove(Text child) {
				removeChild(child, "facets");
			}
			public void clear() {
			    super.clear("facets");
			}
		}
	}
}

==> ui-framework-4.6.2-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractWidgetSummaryMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractWidgetSummaryMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, io.intino.alexandria.schemas.Widget, B> {
	public Doc_27_1_01474993905 doc_27_1_01474993905;
	public WidgetSummaryMold.Doc_27_1_01474993905. Title title;
	public WidgetSummaryMold.Doc_27_1_01474993905. Doc_29_2_1203325673 doc_29_2_1203325673;
	public WidgetSummaryMold.Doc_27_1_01474993905.Doc_29_2_1203325673. Description description;
	public WidgetSummaryMold.Doc_27_1_01474993905. Facets facets;

    public AbstractWidgetSummaryMold(B box) {
        super(box);
        id("widgetSummaryMold");
    }

    @Override
	public void init() {
		super.init();
		if (doc_27_1_01474993905 == null) doc_27_1_01474993905 = register(new Doc_27_1_01474993905(box()).<Doc_27_1_01474993905>id("a628581916").owner(AbstractWidgetSummaryMold.this));
		if (doc_27_1_01474993905 != null) title = doc_27_1_01474993905.title;
		if (doc_27_1_01474993905 != null) doc_29_2_1203325673 = doc_27_1_01474993905.doc_29_2_1203325673;
		if (doc_29_2_1203325673 != null) description = doc_27_1_01474993905.doc_29_2_1203325673.description;
		if (doc_27_1_01474993905 != null) facets = doc_27_1_01474993905.facets;
	}

	public class Doc_27_1_01474993905 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public WidgetSummaryMold.Doc_27_1_01474993905. Title title;
		public WidgetSummaryMold.Doc_27_1_01474993905. Doc_29_2_1203325673 doc_29_2_1203325673;
		public WidgetSummaryMold.Doc_27_1_01474993905. Facets facets;

		public Doc_27_1_01474993905(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (title == null) title = register(new Title(box()).<Title>id("a_1507377868").owner(AbstractWidgetSummaryMold.this));
			if (doc_29_2_1203325673 == null) doc_29_2_1203325673 = register(new Doc_29_2_1203325673(box()).<Doc_29_2_1203325673>id("a_1927398662").owner(AbstractWidgetSummaryMold.this));
			if (facets == null) facets = register(new Facets(box()).<Facets>id("a107217472").owner(AbstractWidgetSummaryMold.this));
		}

		public class Title extends io.intino.alexandria.ui.displays.components.OpenPage<io.intino.alexandria.ui.displays.notifiers.OpenPageNotifier, B>  {

			public Title(B box) {
				super(box);
				_title("");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
				_path("/docs/data/:type/");
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Doc_29_2_1203325673 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public WidgetSummaryMold.Doc_27_1_01474993905.Doc_29_2_1203325673. Description description;

			public Doc_29_2_1203325673(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (description == null) description = register(new Description(box()).<Description>id("a2023875803").owner(AbstractWidgetSummaryMold.this));
			}

			public class Description extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Description(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class Facets extends io.intino.alexandria.ui.displays.components.Multiple<B,Text, java.lang.String>  {

			public Facets(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public Text add(java.lang.String value) {
				Text child = new Text(box());
				child.id(java.util.UUID.randomUUID().toString());
				add(child, "facets");
				child.value(value);
			    notifyAdd(child, value);
				return child;
			}
			@Override
			public void remove(Text child) {
				removeChild(child, "facets");
			}
			public void clear() {
			    super.clear("facets");
			}
		}
	}
}
